﻿using SfDataGrid_Demo.Service_References.ServiceReference1;
using Simple.OData.Client;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Xamarin.Forms;
using System.Reflection;
using System.Diagnostics;
using System.Net.Http;
using System.Net.Http.Headers;
using Newtonsoft.Json;
using System.Data.Services.Client;
using System.Net;
using Syncfusion.SfDataGrid.XForms;

namespace SfDataGrid_Demo
{
    public class ViewModel: INotifyPropertyChanged
    {
        #region Properties

        NorthwindEntities northwindEntity;
        HttpClient client;

        private IncrementalList<Order> gridSource;
        public IncrementalList<Order> GridSource
        {
            get { return gridSource; }
            set { this.gridSource = value; }
        }


        #endregion

        #region Ctor

        public ViewModel()
        {
            GridSource = new IncrementalList<Order>(LoadMoreItems) { MaxItemCount = 1000 };
            client = new HttpClient();
            client.MaxResponseContentBufferSize = 256000;
        }

        public async void LoadMoreItems(uint count, int baseIndex)
        {
                string url = "http://services.odata.org/Northwind/Northwind.svc/";
                if (CheckConnection(url))
                {
                    northwindEntity = new NorthwindEntities(new Uri(url));
                    DataServiceQuery<Order> query = northwindEntity.Orders.Expand("Customer");
                    query = query.Skip<Order>(gridSource.Count).Take<Order>(50) as DataServiceQuery<Order>;
                    IAsyncResult ar = query.BeginExecute(null, null);
                    var items = query.EndExecute(ar);
                    var list = items.ToList();
                    foreach (var item in list)
                    {
                        gridSource.Add(item);
                    }
                    await Task.Delay(2000);
                    GridSource.LoadItems(list);
                }
                else
                {
                   await App.Current.MainPage.DisplayAlert("Attention","Internet was not connected, please connect with Internet", "OK");
                }
        }

        #endregion

        #region INotifyPropertyChanged Member

        public event PropertyChangedEventHandler PropertyChanged;

        void RaisePropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }


        private bool CheckConnection(String URL)
        {
            try
            {
                HttpWebRequest request = (HttpWebRequest)HttpWebRequest.Create(new Uri(URL));
                request.Credentials = CredentialCache.DefaultNetworkCredentials;
                if (request.GetResponseAsync().Wait(5000)){
                    HttpWebResponse response = (HttpWebResponse)request.GetResponseAsync().GetAwaiter().GetResult();

                    if (response.StatusCode == HttpStatusCode.OK)
                        return true;
                    else
                        return false;
                }
                else
                  return false;
            }
            catch
            {
                return false;
            }
        }

        #endregion
    }
}
